@@ -53,7 +53,6 @@ import java.security.GeneralSecurityException;
 import java.util.List;
 import org.apache.commons.httpclient.cookie.CookiePolicy;
 import org.apache.commons.logging.Log;
-import com.openexchange.log.LogFactory;
 import org.ho.yaml.Yaml;
 import com.gargoylesoftware.htmlunit.BrowserVersion;
 import com.gargoylesoftware.htmlunit.BrowserVersionFeatures;
@@ -66,6 +65,7 @@ import com.gargoylesoftware.htmlunit.Page;
 import com.gargoylesoftware.htmlunit.ThreadedRefreshHandler;
 import com.gargoylesoftware.htmlunit.WebClient;
 import com.openexchange.exception.OXException;
+import com.openexchange.log.LogFactory;
 import com.openexchange.subscribe.Subscription;
 import com.openexchange.subscribe.SubscriptionErrorMessage;
 import com.openexchange.subscribe.crawler.internal.HasLoginPage;
@@ -82,7 +82,7 @@ import com.openexchange.subscribe.crawler.osgi.Activator;
  */
 public class Workflow {
 
-    private List<Step> steps;
+    private List<Step<?, ?>> steps;
 
     private String loginStepString;
 
@@ -103,17 +103,25 @@ public class Workflow {
     private boolean quirkyCookieQuotes;
 
     public Workflow() {
-
+        super();
     }
 
-    public Workflow(final List<Step> steps) {
+    public Workflow(final List<Step<?, ?>> steps) {
+        super();
         this.steps = steps;
         useThreadedRefreshHandler = false;
     }
 
     // Convenience method for setting username and password after the workflow was created
     public Object[] execute(final String username, final String password) throws OXException {
-        for (final Step currentStep : steps) {
+        // Ensure username and password are not null
+        if (null == username) {
+            throw SubscriptionErrorMessage.MISSING_ARGUMENT.create("username");
+        }
+        if (null == password) {
+            throw SubscriptionErrorMessage.MISSING_ARGUMENT.create("password");
+        }
+        for (final Step<?, ?> currentStep : steps) {
             if (debuggingEnabled) {
                 currentStep.setDebuggingEnabled(true);
             }
@@ -167,7 +175,7 @@ public class Workflow {
         }
         try {
 
-            Step previousStep = null;
+            Step<?, ?> previousStep = null;
             Object result = null;
 
             for (final Step currentStep : steps) {
@@ -208,33 +216,20 @@ public class Workflow {
 
             webClient.closeAllWindows();
             return (Object[]) result;
-        }
-        catch (NullPointerException e) {
-            LOG.error(e);
-            String stacktrace = "";
-            for (StackTraceElement element : e.getStackTrace()){
-                stacktrace += element + "\n";
-            }
-            LOG.error(stacktrace);
-            LOG.error("User with id="+subscription.getUserId()+ " and context="+ subscription.getContext()+" failed to subscribe source="+subscription.getSource().getDisplayName()+" with display_name="+subscription.getDisplayName());
-            throw SubscriptionErrorMessage.TEMPORARILY_UNAVAILABLE.create();
-        }
-        catch (ClassCastException e) {
-            LOG.error(e);
-            LOG.error("User with id="+subscription.getUserId()+ " and context="+ subscription.getContext()+" failed to subscribe source="+subscription.getSource().getDisplayName()+" with display_name="+subscription.getDisplayName());
-            throw SubscriptionErrorMessage.TEMPORARILY_UNAVAILABLE.create();
-        }
-        finally {
+        } catch (RuntimeException e) {
+            LOG.error("User with id="+subscription.getUserId()+ " and context="+ subscription.getContext()+" failed to subscribe source="+subscription.getSource().getDisplayName()+" with display_name="+subscription.getDisplayName(), e);
+            throw SubscriptionErrorMessage.TEMPORARILY_UNAVAILABLE.create(e);
+        } finally {
             /*MultiThreadedHttpConnectionManager manager = (MultiThreadedHttpConnectionManager) crawlerConnection.getHttpClient().getHttpConnectionManager();
             manager.shutdown(); */
         }
     }
 
-    public List<Step> getSteps() {
+    public List<Step<?, ?>> getSteps() {
         return steps;
     }
 
-    public void setSteps(final List<Step> steps) {
+    public void setSteps(final List<Step<?, ?>> steps) {
         this.steps = steps;
     }
 
@@ -305,7 +300,7 @@ public class Workflow {
     }
 
     // This should help to better understand why a step failed. May need to be expanded for other complex inputs without helpful toString()-Method ...
-    private void logBadInput(Step currentStep){
+    private void logBadInput(Step<?, ?> currentStep){
         if (currentStep.getInput() != null){
             if (currentStep.getInput() instanceof Page){
                 LOG.error("Bad Input causing the error at (" + currentStep.getClass() + ") : " + ((Page) currentStep.getInput()).getWebResponse().getContentAsString());
