@@ -67,15 +67,15 @@ public class SubscriptionJSONExceptionMessage implements LocalizableStrings {
 
     public final static String MISSING_PARAMETER_MSG = "Missing parameter %s";
 
-    public final static String UNKNOWN_ACTION_MSG = "Unknown Action: %s";
+    public final static String UNKNOWN_ACTION_MSG = "Unknown action: %s";
 
-    public final static String JSONEXCEPTION_MSG = "Got JSONException";
+    public final static String JSONEXCEPTION_MSG = "A JSON error occurred";
 
-    public final static String MISSING_FIELD_MSG = "Missing Field(s): %s";
+    public final static String MISSING_FIELD_MSG = "Missing field(s): %s";
 
-    public final static String MISSING_FORM_FIELD_MSG = "Missing Form Field(s): %s";
+    public final static String MISSING_FORM_FIELD_MSG = "Missing form field(s): %s";
 
-    public final static String THROWABLE_MSG = "Got Exception %s";
+    public final static String THROWABLE_MSG = "An unexpected error occurred: %s";
 
     public final static String UNKNOWN_COLUMN_MSG = "Unknown column: %s";
 
@@ -93,6 +93,6 @@ public class SubscriptionJSONExceptionMessage implements LocalizableStrings {
 
     public final static String UNKNOWN_COLUMN_HELP = "Please ask only for columns the server knows";
 
-	public static final String UNKNOWN_SUBSCRIPTION = "Unknown Subscription";
+	public static final String UNKNOWN_SUBSCRIPTION = "Unknown subscription";
 
 }
