@@ -56,40 +56,35 @@ import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXActionServiceFactory;
 import com.openexchange.exception.OXException;
 import com.openexchange.server.ServiceLookup;
+import com.openexchange.tools.servlet.AjaxExceptionCodes;
 
 /**
- *
  * @author <a href="mailto:karsten.will@open-xchange.com">Karsten Will</a>
- *
  */
 public class SubscriptionActionFactory implements AJAXActionServiceFactory {
 
-	private final Map<String, AJAXActionService> actions = new ConcurrentHashMap<String, AJAXActionService>(8);
+    private final Map<String, AJAXActionService> actions = new ConcurrentHashMap<String, AJAXActionService>(12);
 
+    public SubscriptionActionFactory(final ServiceLookup services) {
+        super();
+        actions.put("new", new NewSubscriptionAction(services));
+        actions.put("get", new GetSubscriptionAction(services));
+        actions.put("all", new AllSubscriptionAction(services));
+        actions.put("list", new ListSubscriptionAction(services));
+        actions.put("update", new UpdateSubscriptionAction(services));
+        actions.put("refresh", new RefreshSubscriptionAction(services));
+        actions.put("delete", new DeleteSubscriptionAction(services));
+    }
 
-	public SubscriptionActionFactory(final ServiceLookup services) {
-		actions.put("new", new NewSubscriptionAction(services));
-		actions.put("get", new GetSubscriptionAction(services));
-		actions.put("all", new AllSubscriptionAction(services));
-		actions.put("list", new ListSubscriptionAction(services));
-		actions.put("update", new UpdateSubscriptionAction(services));
-		actions.put("refresh", new RefreshSubscriptionAction(services));
-		actions.put("delete", new DeleteSubscriptionAction(services));
-	}
+    @Override
+    public AJAXActionService createActionService(final String action) throws OXException {
+        if (actions.containsKey(action)) {
+            return actions.get(action);
+        }
+        throw AjaxExceptionCodes.UNKNOWN_ACTION.create(action);
+    }
 
-
-	@Override
-    public AJAXActionService createActionService(final String action)
-			throws OXException {
-		if (actions.containsKey(action)){
-			return actions.get(action);
-		} else {
-			// TODO: fill this exception
-			throw new OXException();
-		}
-	}
-
-	@Override
+    @Override
     public Collection<? extends AJAXActionService> getSupportedServices() {
         return java.util.Collections.unmodifiableCollection(actions.values());
     }
